Ecommerce Dashboard — Stisla

Order Statistics -
August
24
Pending
12
Shipping
23
Completed

#### Total Orders

59

#### Balance

$187,13

#### Sales

4,732

#### Budget vs Sales

#### Top 5 Products

Month

- 86 Sales
  oPhone S9 Limited
  $68,714
  $38,700
- 67 Sales
  iBook Pro 2018
  $107,133
  $91,455
- 63 Sales
  Headphone Blitz
  $3,717
  $2,835
- 28 Sales
  oPhone X Lite
  $13,972
  $9,660
- 19 Sales
  Old Camera
  $7,391
  $5,472

#### Best Products

iBook Pro 2018
67 Sales
Detail
oPhone S9 Limited
86 Sales
Detail
Headphone Blitz
63 Sales
Detail

#### Top Countries

July

- Indonesia
  3,282
- Malaysia
  2,976
- United States
  1,576

August

- Indonesia
  3,486
- Palestine
  3,182
- Germany
  2,317

#### Invoices

View More

Invoice ID | Customer | Status | Due Date | Action
--- | --- | --- | --- | ---
INV-87239 | Kusnadi | Unpaid | July 19, 2018 | Detail
INV-48574 | Hasan Basri | Paid | July 21, 2018 | Detail
INV-76824 | Muhamad Nuruzzaki | Unpaid | July 22, 2018 | Detail
INV-84990 | Agung Ardiansyah | Unpaid | July 22, 2018 | Detail
INV-87320 | Ardian Rahardiansyah | Paid | July 28, 2018 | Detail

#### 14

Customers need help

#### My order hasn't arrived yet

Laila Tazkiah
1 min ago

#### Please cancel my order

Rizal Fakhri
2 hours ago

#### Do you see my mother?

Syahdan Ubaidillah
6 hours ago
View All